@@ -1,6 +1,6 @@
 package Lemonldap::NG::Handler::Main::Reload;
 
-our $VERSION = '2.17.0';
+our $VERSION = '2.18.0';
 
 package Lemonldap::NG::Handler::Main;
 
@@ -538,57 +538,13 @@ sub conditionSub {
         );
     }
 
-    # Since filter exists only with Apache>=2, logout_app and logout_app_sso
-    # targets are available only for it.
-    # This error can also appear with Manager configured as CGI script
-    if ( $cond =~ /^logout_app/i
-        and not $class->isa('Lemonldap::NG::Handler::ApacheMP2::Main') )
-    {
-        $class->logger->info(
-            "Rules logout_app and logout_app_sso require Apache>=2");
-        return ( sub { 1 }, 0 );
-    }
-
     # logout_app
     if ( $cond =~ /^logout_app(?:\s+(.*))?$/i ) {
-        my $u = $1 || $class->tsv->{portal}->();
-        $class->logger->debug("logout_app redirect to $u");
-        eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
-        return (
-            sub {
-                $_[0]->{env}->{'psgi.r'}->add_output_filter(
-                    sub {
-                        return $class->redirectFilter( $u, @_ );
-                    }
-                );
-                1;
-            },
-            0
-        );
+        return $class->logout_app($1);
     }
+    # logout_app_sso
     elsif ( $cond =~ /^logout_app_sso(?:\s+(.*))?$/i ) {
-        my $u = $1 || $class->tsv->{portal}->();
-        $class->logger->debug("logout_app_sso redirect to $u");
-        eval 'use Apache2::Filter' unless ( $INC{"Apache2/Filter.pm"} );
-        return (
-            sub {
-                my ($req) = @_;
-                $class->localUnlog( $req, @_ );
-                $req->{env}->{'psgi.r'}->add_output_filter(
-                    sub {
-                        my $r = $_[0]->r;
-                        return $class->redirectFilter(
-                            &{ $class->tsv->{portal} }() . "?url="
-                              . $class->encodeUrl( $req, $u )
-                              . "&logout=1",
-                            @_
-                        );
-                    }
-                );
-                1;
-            },
-            0
-        );
+        return $class->logout_app_sso($1);
     }
 
     my $mayskip = 0;
